@@ -1,3 +1,3 @@
 from kplot.lib import *
 
-kplot.lib.loadtheme("kg")
+loadtheme("kg")
